==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/main/dialogs/selectablesubtitledialog.h <==
#ifndef SELECTABLESUBTITLEDIALOG_H
#define SELECTABLESUBTITLEDIALOG_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include "actiondialog.h"

#include <klocale.h>

class QGridLayout;
class QGroupBox;
class KLineEdit;
class KComboBox;

namespace SubtitleComposer
{
	class SelectableSubtitleDialog : public ActionDialog
	{
		Q_OBJECT

		public:

			SelectableSubtitleDialog( const QString& defaultEncoding, const QString& title, QWidget* parent=0 );

			QString subtitlePath();
			QString subtitleEncoding();

		protected:

			QGroupBox* createSubtitleGroupBox( const QString& title=i18n( "Subtitle" ), bool addToLayout=true );

		private slots:

			void selectSubtitle();

		protected:

			QGroupBox* m_subtitleGroupBox;
			QGridLayout* m_subtitleLayout;

			KLineEdit* m_subtitlePathLineEdit;
			KComboBox* m_subtitleEncodingComboBox;

			QString m_defaultEncoding;
	};
}

#endif

==> subtitlecomposer-0.4.3.tar.bz2: subtitlecomposer-0.4.3/src/main/dialogs/selectablesubtitledialog.h <==
#ifndef SELECTABLESUBTITLEDIALOG_H
#define SELECTABLESUBTITLEDIALOG_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include "actionwithtargetdialog.h"

#include <klocale.h>

class QGridLayout;
class QButtonGroup;
class KLineEdit;
class KComboBox;

namespace SubtitleComposer
{
	class SelectableSubtitleDialog : public ActionWithTargetDialog
	{
		Q_OBJECT

		public:

			SelectableSubtitleDialog( const QString& defaultEncoding, const QString& title, QWidget* parent=0 );

			QString subtitlePath() const;
			QString subtitleEncoding() const;

		protected:

			QButtonGroup* createSubtitleButtonGroup( const QString& title=i18n( "Subtitle" ), bool addToLayout=true );

		private slots:

			void selectSubtitle();

		protected:

			QButtonGroup* m_subtitleButtonGroup;
			QGridLayout* m_subtitleLayout;

			KLineEdit* m_subtitlePathLineEdit;
			KComboBox* m_subtitleEncodingComboBox;

			QString m_defaultEncoding;
	};
}

#endif
